searchData={"items":[{"type":"module","title":"LiveToast","doc":"LiveComponent for displaying toast messages.","ref":"LiveToast.html"},{"type":"function","title":"LiveToast.put_toast/4","doc":"Helper function around `send_toast/3` that is useful in pipelines.\nCan be used in a pipeline with either Plug.Conn or LiveView.Socket.\n\nUnlike `send_toast/3`, this function does expose the UUID of the\nnew toast, so if you need to update the toast after popping it onto\nthe list, you should use `send_toast/3` directly.","ref":"LiveToast.html#put_toast/4"},{"type":"function","title":"Examples - LiveToast.put_toast/4","doc":"iex> put_toast(conn, :info, \"Thank you for logging in!\")\n%Plug.Conn{...}\n\niex> put_toast(socket, :info, \"Thank you for logging in!\")\n%LiveView.Socket{...}","ref":"LiveToast.html#put_toast/4-examples"},{"type":"function","title":"LiveToast.send_toast/3","doc":"Send a new toast message to the LiveToast component.\n\nReturns the UUID of the new toast message. This UUID can be passed back\nto another call to `send_toast/3` to update the properties of an existing toast.","ref":"LiveToast.html#send_toast/3"},{"type":"function","title":"Examples - LiveToast.send_toast/3","doc":"iex> send_toast(:info, \"Thank you for logging in!\", title: \"Welcome\")\n\"00c90156-56d1-4bca-a9e2-6353d49c974a\"","ref":"LiveToast.html#send_toast/3-examples"},{"type":"function","title":"LiveToast.toast_class_fn/1","doc":"Implement your own function to override the class of the toasts.","ref":"LiveToast.html#toast_class_fn/1"},{"type":"function","title":"Examples: - LiveToast.toast_class_fn/1","doc":"```elixir\ndefmodule MyModule do\n  def toast_class_fn(assigns) do\n    [\n      \"group/toast z-100 pointer-events-auto relative w-full items-center justify-between origin-center overflow-hidden rounded-lg p-4 shadow-lg border col-start-1 col-end-1 row-start-1 row-end-2\",\n      if(assigns[:rest][:hidden] == true, do: \"hidden\", else: \"flex\"),\n      assigns[:kind] == :info && \" bg-white text-black\",\n      assigns[:kind] == :error && \"!text-red-700 !bg-red-100 border-red-200\"\n    ]\n  end\nend\n```\n\nThen use it in your layout:\n\n```heex\n \n```","ref":"LiveToast.html#toast_class_fn/1-examples"},{"type":"function","title":"LiveToast.toast_group/1","doc":"Renders a group of toasts and flashes.\nReplace your `flash_group` with this component in your layout.","ref":"LiveToast.html#toast_group/1"},{"type":"function","title":"Attributes - LiveToast.toast_group/1","doc":"* `flash` (`:map`) (required) - the map of flash messages.\n* `id` (`:string`) - the optional id of flash container. Defaults to `\"toast-group\"`.\n* `connected` (`:boolean`) - whether we're in a liveview or not. Defaults to `false`.\n* `corner` (`:atom`) - the corner to display the toasts. Defaults to `:bottom_right`.\n* `toast_class_fn` (`:any`) - function to override the look of the toasts. Defaults to `&LiveToast.toast_class_fn/1`.","ref":"LiveToast.html#toast_group/1-attributes"},{"type":"type","title":"LiveToast.component_fn/0","doc":"`Phoenix.Component` that renders a part of the toast message.","ref":"LiveToast.html#t:component_fn/0"},{"type":"type","title":"LiveToast.option/0","doc":"Set of public options to augment the default toast behavior.","ref":"LiveToast.html#t:option/0"},{"type":"opaque","title":"LiveToast.t/0","doc":"Instance of a toast message. Mainly used internally.","ref":"LiveToast.html#t:t/0"},{"type":"module","title":"LiveToast.Components","doc":"This module defines the components used in the rendering of the default toast messages.\nYou can use this as a reference to create your own version of these components.","ref":"LiveToast.Components.html"},{"type":"function","title":"LiveToast.Components.flash_group/1","doc":"","ref":"LiveToast.Components.html#flash_group/1"},{"type":"function","title":"Attributes - LiveToast.Components.flash_group/1","doc":"* `flash` (`:map`) (required) - the map of flash messages.\n* `id` (`:string`) - the optional id of flash container. Defaults to `\"toast-group\"`.\n* `corner` (`:atom`) - the corner to display the toasts. Defaults to `:bottom_right`.\n* `toast_class_fn` (`:any`) - function to override the look of the toasts. Defaults to `&LiveToast.toast_class_fn/1`.","ref":"LiveToast.Components.html#flash_group/1-attributes"},{"type":"function","title":"LiveToast.Components.flashes/1","doc":"","ref":"LiveToast.Components.html#flashes/1"},{"type":"function","title":"Attributes - LiveToast.Components.flashes/1","doc":"* `f` (`:map`) (required) - the map of flash messages.\n* `corner` (`:atom`) - the corner to display the toasts. Defaults to `:bottom_right`.\n* `toast_class_fn` (`:any`) - function to override the look of the toasts. Defaults to `&LiveToast.toast_class_fn/1`.","ref":"LiveToast.Components.html#flashes/1-attributes"},{"type":"function","title":"LiveToast.Components.toast/1","doc":"","ref":"LiveToast.Components.html#toast/1"},{"type":"function","title":"Attributes - LiveToast.Components.toast/1","doc":"* `id` (`:string`) - the optional id of flash container.\n* `flash` (`:map`) - the map of flash messages to display. Defaults to `%{}`.\n* `title` (`:string`) - Defaults to `nil`.\n* `kind` (`:atom`) - used for styling and flash lookup.Must be one of `:info`, or `:error`.\n* `target` (`:any`) - the target for the phx-click event. Defaults to `nil`.\n* `duration` (`:integer`) - the time in milliseconds before the message is automatically dismissed. Defaults to `6000`.\n* `class_fn` (`:any`) (required) - function to override the look of the toasts.\n* `corner` (`:atom`) (required) - the corner to display the toasts.\n* `icon` (`:any`) - the optional icon to render in the flash message. Defaults to `nil`.\n* `action` (`:any`) - the optional action to render in the flash message. Defaults to `nil`.\n* `component` (`:any`) - the optional component to render the flash message. Defaults to `nil`.\n* Global attributes are accepted. the arbitrary HTML attributes to add to the flash container.","ref":"LiveToast.Components.html#toast/1-attributes"},{"type":"function","title":"Slots - LiveToast.Components.toast/1","doc":"* `inner_block` - the optional inner block that renders the flash message.","ref":"LiveToast.Components.html#toast/1-slots"},{"type":"task","title":"mix docs.run","doc":"Run documentation server.","ref":"Mix.Tasks.Docs.Run.html"},{"type":"function","title":"Mix.Tasks.Docs.Run.run/1","doc":"","ref":"Mix.Tasks.Docs.Run.html#run/1"},{"type":"extras","title":"Live Toast","doc":"# Live Toast\n\n![CI](https://github.com/srcrip/live_toast/actions/workflows/tests.yml/badge.svg) [![Hex](https://img.shields.io/hexpm/v/live_toast)](https://hex.pm/packages/live_toast)\n\nLive Toast is a drop-in replacement for the flash system in Phoenix/LiveView.","ref":"readme.html"},{"type":"extras","title":"Installation - Live Toast","doc":"Add `live_toast` to your list of dependencies in the `mix.exs` of your Phoenix\napplication:\n\n```elixir\ndef deps do\n  [\n    {:live_toast, \"~> 0.5.0\"}\n  ]\nend\n```\n\nNext open up your `app.js` and import/setup the hook (Note that if you bundle through some external bundler, you may need to import from `../deps/live_toast`):\n\n```javascript\nimport { createLiveToastHook } from 'live_toast'\n\nlet liveSocket = new LiveSocket('/live', Socket, {\n  hooks: {\n    LiveToast: createLiveToastHook()\n  }\n})\n```\n\nThen, add `'../deps/live_toast/lib/**/*.*ex'` to your list of paths Tailwind will look for class names, in your\n`tailwind.config.js`:\n\n```javascript\n// assets/tailwind.config.js\n\nmodule.exports = {\n  content: [\n    './js/**/*.js',\n    '../lib/your_app_web.ex',\n    '../lib/your_app_web/**/*.*ex',\n    '../deps/live_toast/lib/**/*.*ex',\n  ]\n}\n```\n\nYour particular file will look different but all you need to do is make sure the last line is there.\n\nNote that the classes are currently hardcoded. Configuration of the toast components, and therefore there styling, are\non the roadmap. But the default styles should look pretty good in the mean time.\n\nFinally, replace your `<.flash_group />` component with the new ` `. It's most likely in your\n`app.html.heex`:\n\n```heex\n<!-- Remove this! -->\n<.flash_group flash={@flash} />\n\n<!-- And replace it with this: -->\n \n\n<%= @inner_content %>\n```\n\nAnd you're done! Note that it's very important to set `connected` based on whether we're in a LiveView or not. This\ncontrols toast/flash display on non-LiveView pages.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Live Toast","doc":"`LiveToast` will hijack the usual display of your flash messages, so they will continue to work as normal. You can\ncontinue to use flashes as normal, if you want to.\n\nHowever, one of the reasons to *not* use flash messages, is the Phoenix flash system only allows one message for each\nkind of flash. The toast pattern, alternatively, generally allows for multiple messages displayed to the user at at time.\n\nFrom a LiveView, you can now use `send_toast`:\n\n```elixir\ndefmodule YourApp.SomeLiveView do\n  def handle_event(\"submit\", _payload, socket) do\n    # you do some thing with the payload, then you want to show a toast, so:\n    LiveToast.send_toast(:info, \"Upload successful.\")\n\n    {:noreply, socket}\n  end\nend\n```\n\nOr you can use the helper function, `put_toast`, similar to how you may use `put_flash`:\n\n```elixir\ndefmodule YourApp.SomeLiveView do\n  def handle_event(\"submit\", _payload, socket) do\n    socket = socket\n    |> put_toast(:info, \"Upload successful.\")\n\n    {:noreply, socket}\n  end\nend\n```\n\n`put_toast` can take a `Phoenix.LiveView.Socket` or a `Plug.Conn`, so you can use the same thing in your live and\nnon-live pages.\n\n```elixir\ndefmodule YourApp.SomeController do\n  def create(conn, _params) do\n    conn\n    |> put_toast(:info, \"Upload successful.\")\n    |> render(:whatever)\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Configuration - Live Toast","doc":"","ref":"readme.html#configuration"},{"type":"extras","title":"Setting the corner - Live Toast","doc":"You can change which corner the toasts are anchored to by passing the `corner` setting to `toast_group`, one of either `:top_left`, `:top_right`, `:bottom_left`, `:bottom_right`. The default is `:bottom_right`.\n\n```heex\n \n```","ref":"readme.html#setting-the-corner"},{"type":"extras","title":"Function Options - Live Toast","doc":"`send_toast` takes a number of arguments to control it's behavior. They are currently:\n\n- `kind`: The 'level' of this toast. The `component` function can receive this and modify behavior based on severity.\n    the `toast_class_fn` also receives it, and it can be used there to modify styles, for example, making `:info` toasts\n    green and `:error` toasts red.\n- `body`: The primary text of the message. \n- `title`: The optional title of the toast displayed at the top.\n- `icon`: An optional function component that renders next to the title. You can use this with the default toast to display an icon.\n- `action`: An optional function component that renders to the side. You can use this with the default toast to display an action, like a button.\n- `component`: Use this to totally override rendering of the toast. This is expected to be a function component that\n    will receive all of the above options. See [this part of the demo]() as an example.\n\nNote that if you use more than just `:info` and `:error` in your codebase for flashes, you can augment Livetoast using\nsome of the methods below to support that.","ref":"readme.html#function-options"},{"type":"extras","title":"Custom Classes - Live Toast","doc":"You can define a custom toast class function, like so:\n\n```elixir\ndefmodule MyModule do\n  def toast_class_fn(assigns) do\n    [\n      \"group/toast z-100 pointer-events-auto relative w-full items-center justify-between origin-center overflow-hidden rounded-lg p-4 shadow-lg border col-start-1 col-end-1 row-start-1 row-end-2\",\n      if(assigns[:rest][:hidden] == true, do: \"hidden\", else: \"flex\"),\n      assigns[:kind] == :info && \" bg-white text-black\",\n      assigns[:kind] == :error && \"!text-red-700 !bg-red-100 border-red-200\"\n    ]\n  end\nend\n\n```\n\nAnd then use it to override the default styles:\n\n```heex\n \n```","ref":"readme.html#custom-classes"},{"type":"extras","title":"JavaScript Options - Live Toast","doc":"You can also change some options about the LiveView hook when it is initalized. Such as:\n\n```javascript\nimport { createLiveToastHook } from 'live_toast'\n\n// the duration for each toast to stay on screen in ms\nconst duration = 4000\n\n// how many toasts to show on screen at once\nconst maxItems = 3\n\nconst liveToastHook = createLiveToastHook(duration, maxItems)\n\nlet liveSocket = new LiveSocket('/live', Socket, {\n  hooks: { LiveToast: liveToastHook }\n})\n```","ref":"readme.html#javascript-options"},{"type":"extras","title":"Roadmap - Live Toast","doc":"Some of the stuff still to work on:\n\n- [ ] Improved docs\n- [ ] Configuration for the classes on toasts\n- [ ] more tests\n- [ ] More configuration for the animations\n- [ ] Ability to have more flashes than the default :error and :info (like a :warn)\n- [ ] Update a toast live (showing progress for example), and a recipe entry on this","ref":"readme.html#roadmap"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\n## [v0.1.0] (2024-03-06)\n\n🚀 Initial release.\n\n## [v0.2.0] (2024-03-08)\n\nBug fixes:\n- JS.Show on the flashes now correctly toggles them to display flex instead of block\n- The component functions properly when used in non-liveviews\n\n## [v0.3.0] (2024-03-12)\n\nBug fixes:\n- Fixing quite a few little problems here and there\n- Adding more configuration\n\n## [v0.4.0] (2024-05-11)\n\nMassive overhaul of look and feel.\n\n## [v0.4.1] (2024-05-11)\n\nDemo repo bug fixing.\n\n## [v0.4.2] (2024-05-15)\n\nTightening up a few bugs found during the creation of the demo.\n\n## [v0.4.3] (2024-05-15)\n\nFix implementation of `send_toast`.","ref":"changelog.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}